@@ -61,10 +61,10 @@ struct XorrisO;
 */
 #define Xorriso_header_version_majoR  1
 #define Xorriso_header_version_minoR  1
-#define Xorriso_header_version_micrO  2
+#define Xorriso_header_version_micrO  8
 
 
-/** Eventually something like ".pl01" to indicate a bug fix. Normally empty.
+/** If needed: Something like ".pl01" to indicate a bug fix. Normally empty.
     @since 0.5.8
 */
 #define Xorriso_program_patch_leveL ""
@@ -237,8 +237,10 @@ int Xorriso_destroy(struct XorrisO **xorriso, int flag);
      -abort_on , -report_about , -return_with , -list_delimiter ,
      -scsi_log , -signal_handling
    Some commands get executed only if they are the only command in argv:
-     -prog_help , -help , -no_rc
-   Some get examined for the need to redirect stdout messages
+     -prog_help , -help
+   The following is recognized only if it is the first of all arguments:
+     -no_rc
+   Some get examined for the need to redirect stdout messages:
      -dev , -outdev , -indev , -as 
    Commands -list_delimiter and -add_plainly get into effect during this
    call. But their setting at begin of the call gets restored before the
@@ -790,7 +792,8 @@ int Xorriso_option_cut_out(struct XorrisO *xorriso, char *disk_path,
 int Xorriso_option_dev(struct XorrisO *xorriso, char *adr, int flag);
 
 /* Option -devices */
-/* @return <=0 error , 1 success, 2 revoked by -reassure
+/* @param flag bit0= perform -device_links rather than -devices
+   @return <=0 error , 1 success, 2 revoked by -reassure
 */
 int Xorriso_option_devices(struct XorrisO *xorriso, int flag);
 
@@ -919,6 +922,9 @@ int Xorriso_option_joliet(struct XorrisO *xorriso, char *mode, int flag);
 int Xorriso_option_list_delimiter(struct XorrisO *xorriso, char *text,
                                   int flag);
 
+/* Option -list_extras */
+int Xorriso_option_list_extras(struct XorrisO *xorriso, char *mode, int flag);
+
 /* Option -list_formats */
 int Xorriso_option_list_formats(struct XorrisO *xorriso, int flag);
 
@@ -1172,6 +1178,9 @@ int Xorriso_option_set_filter(struct XorrisO *xorriso, char *name,
 int Xorriso_option_signal_handling(struct XorrisO *xorriso, char *mode,
                                    int flag);
 
+/* Option -sleep */
+int Xorriso_option_sleep(struct XorrisO *xorriso, char *duration, int flag);
+
 /* Option -speed */
 int Xorriso_option_speed(struct XorrisO *xorriso, char *speed, int flag);
 
